@@ -1,5 +1,6 @@
-from ... import configuration
-from ... import pyc_checker
+import os
+from ... import configuration, pyc_checker
+from ...pyc_checker import extensions
 from concurrent.futures import ThreadPoolExecutor
 import multiprocessing
 import time
@@ -31,13 +32,13 @@ class PackageStruct:
         # TODO log error from dump
         try:
             t = configuration.thread_timeout
-            code, err = pyc_checker.dump_pyc(file, f'{file}.py', t)
+            code, err = pyc_checker.dump_pyc(file, file, t)
             if code:
-                print('[+] decompiler bytecode', file, len(code))
+                print('[+] decompile bytecode', file, len(code))
             else:
-                print('[!] fail to decompiler bytecode', file, err)
+                print('[!] fail to decompile bytecode', file, err)
         except Exception as e:
-            print('[!] Exception on decompiler bytecode', file, e)
+            print('[!] Exception on decompile bytecode', file, e)
 
     def callback_pyc_decompile(self, f: str):
         PackageStruct.decompile_pyc(f)
@@ -64,7 +65,7 @@ class PackageStruct:
                 c = f'cost:{cost_time},timeout={time_out}'
                 raise Exception(f'{t}\n{c}\n')
             time.sleep(1)
-            print('\r', f'[*] {description}:{self.handle_count}/{self.total_count}',
+            print('\r', f'[*] {description}:{self.handle_count}{os.path.sep}{self.total_count}',
                   end='', flush=True)
             if self.handle_count > 0 and self.handle_count >= self.total_count:
                 break
@@ -95,7 +96,13 @@ class PackageStruct:
 
     def start_pyz_handle(self):
         if self.encrypt_key_file:
-            src_file = f'{self.encrypt_key_file}.py'
+            src_file = extensions.get_pycdc_path(
+                self.encrypt_key_file)
+            if not os.path.exists(src_file):
+                src_file = f'{extensions.get_uncompyle6_path(self.encrypt_key_file)}'
+            if not os.path.exists(src_file):
+                raise Exception(
+                    'target file seems encrypted,but encrypt_key fetch fail.')
             with open(src_file, encoding='utf-8') as f:
                 content = f.read()
                 g_dict = {'key': None}
